@@ -2,7 +2,9 @@ import logging
 
 from easyprocess import EasyProcess
 
-from pyscreenshot.tempexport import extract_version, read_prog_img
+from pyscreenshot.plugins.backend import CBackend
+from pyscreenshot.tempexport import read_prog_img
+from pyscreenshot.util import extract_version
 
 log = logging.getLogger(__name__)
 
@@ -10,15 +12,12 @@ log = logging.getLogger(__name__)
 PROGRAM = "scrot"
 
 
-class ScrotWrapper(object):
+class ScrotWrapper(CBackend):
     name = "scrot"
-    childprocess = True
+    is_subprocess = True
 
     def __init__(self):
-        p = EasyProcess([PROGRAM, "-version"])
-        p.enable_stdout_log = False
-        p.enable_stderr_log = False
-        p.call()
+        pass
 
     def grab(self, bbox=None):
         im = read_prog_img([PROGRAM, "--silent"])
